from datetime import datetime
#region [Texts]
class Text:
    alphabet = "qwertyuiop[]asdfghjkl;'zxcvbnnm,./1234567890-= !@#$%^&*()_+{}:\"<>?`~QWERTYUIOPASDFGHJKLZXCVBNMйцукенгшщзхъфывапролджэячсмитьбю.\\ЙЦУКЕНГШЩЗХЪФЫВАПРОЛДЖЭЯЧСМИТЬБЮёЁ"
    #region [Encode]
    @staticmethod
    def encode(text: str, password: int = 66) -> str:
        """Encoding string.
        Examples:
            >>> encode("Hello, world!")
            "83|2|20|20|8|31|46|69|8|3|20|14|47"

        Args:
            text (str): String to encode
            password (int, optional): Password to encode. Defaults to 66
        Returns:
            str: Encoded string
        Raises:
            TypeError: If text not an string OR some symbols not in alphabet
        """
        encoded = ''
        for n in list(text):
            encoded += f"{Text.alphabet.index(n)+password}|"
        return encoded[:len(encoded)-1]
    #endregion
    #region [Decode]
    @staticmethod
    def decode(text: str, password: int = 66) -> str:
        """Decoding string.

        Examples:
            >>> decode("83|2|20|20|8|31|46|69|8|3|20|14|47")
            "Hello, world!"

        Args:
            text (str): String to decode
            password (int, optional): Password to decode. Defaults to 66
        Returns:
            str: Decoded string
        Raises:
            TypeError: If text not an string OR some symbols not in alphabet OR password not integer
        """
        texts = text.split("|")
        decoded = ''
        for n in texts:
            decoded += Text.alphabet[int(n)-password]
        return decoded
    #endregion
#endregion
#region [Logging stuff]
class Log:
    @staticmethod
    def info(text: str):
        """Print log.
        
        Examples:
            >>> info("info")
            "2025-07-21, 22:43:28 [INFO] | info"
        
        Args:
            text (str): Text to print.
        """
        print(f"{datetime.now().strftime("%Y-%m-%d, %H:%M:%S")} [INFO] | \033[32m{text}\033[0m")
    @staticmethod
    def warn(text: str):
        """Print log.
        
        Examples:
            >>> warn("warn")
            "2025-07-21, 22:43:28 [WARN] | warn"
        
        Args:
            text (str): Text to print.
        """
        print(f"{datetime.now().strftime("%Y-%m-%d, %H:%M:%S")} [WARN] | \033[33m{text}\033[0m")
    @staticmethod
    def error(text: str):
        """Print log.
        
        Examples:
            >>> error("error")
            "2025-07-21, 22:43:28 [ERROR] | error"
        
        Args:
            text (str): Text to print.
        """
        print(f"{datetime.now().strftime("%Y-%m-%d, %H:%M:%S")} [ERROR] | \033[31m{text}\033[0m")
#endregion
if __name__ == "__main__":
    encoded = Text.encode("Hello, World!", 505)
    print(f"Encoded: {encoded}\nDecoded: {Text.decode(encoded, 505)}")
    Log.info("info")
    Log.error("error")
    Log.warn("warn")